#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    Module sphinx_fontawesome
"""

import os
from sphinx import addnodes
from docutils.nodes import strong, emphasis, reference, Text
from docutils.parsers.rst.roles import set_classes
from docutils.parsers.rst import Directive
import docutils.parsers.rst.directives as directives

import sphinx_fontawesome.constant

__version_info__ = (0, 0, 5)
__version__ = '.'.join([str(val) for val in  __version_info__])

sub_special = [
                {'id' : 'o', 'key' : 'square-o'},
                {'id' : 'x', 'key' : 'check-square-o'},
                {'id' : 'smile', 'key' : 'smile-o'},
                {'id' : 'mail', 'key' : 'envelope'},
                {'id' : 'note', 'key' : 'info-circle'},
              ]
# add role
def fa_global(key=''):
    def fa(role, rawtext, text, lineno, inliner, options={}, content=[]):
        options.update({'classes': []})
        options['classes'].append('fa')
        if key:
            options['classes'].append('fa-%s' % key)
        else:
             for x in text.split(","):
                options['classes'].append('fa-%s' % x)
        set_classes(options)
        node = emphasis(**options)
        return [node], []
    return fa

#add directive
class Fa(Directive):

    has_content = True

    def run(self):
        options= {'classes' : []}
        options['classes'].append('fa')
        for x in self.content[0].split(' '):
            options['classes'].append('fa-%s' % x)
        set_classes(options)
        node = emphasis(**options)
        return [node]
 
prolog = '\n'.join(['.. |%s| fa:: %s' % (icon, icon) for icon in sphinx_fontawesome.constant.icons])
prolog += '\n'
prolog += '\n'.join(['.. |%s| fa:: %s' % (icon['id'], icon['key']) for icon in sub_special])
prolog += '\n'


def setup(app):
    app.add_role('fa', fa_global())
    app.add_directive('fa', Fa)
    app.config.rst_prolog = prolog
    return {'version': __version__}



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import codecs
from setuptools import setup, find_packages

import sphinx_fontawesome

name = "sphinx_fontawesome"
__version_info__ = (0, 0, 5)
version = '.'.join([str(val) for val in  __version_info__])
desc = "add directive for fontawesome in sphinx"
urlpkg = "https://github.com/fraoustin/sphinx_fontawesome"

here = os.path.abspath(os.path.dirname(__file__))

# README AND CHANGES
with open(os.path.join(here, 'README.rst')) as readme:
    with open(os.path.join(here, 'CHANGES.rst')) as changelog:
        long_description = readme.read() + '\n\n' + changelog.read()
# REQUIREMENTS
with open('REQUIREMENTS.txt') as f:
    required = f.read().splitlines()
# CLASSIFIERS
with open('CLASSIFIERS.txt') as f:
    classified = f.read().splitlines()
# AUTHORS
with open('AUTHORS.txt') as f:
    data = f.read().splitlines()
    authors = ','.join([i.split('::')[0] for i in data])
    authors_email = ','.join([i.split('::')[1] for i in data])

setup(
    name = name,
    version = version,
    packages = find_packages(),
    author = authors,
    author_email = authors_email,
    description = desc,
    long_description= long_description,
    include_package_data=True,
    install_requires=required,
    url = urlpkg,
    classifiers=classified,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
    list of icons Font-Awesome
"""

icons = [
	'glass',
	'music',
	'search',
	'envelope-o',
	'heart',
	'star',
	'star-o',
	'user',
	'film',
	'th-large',
	'th',
	'th-list',
	'check',
	'times',
	'remove',
	'close',
	'search-plus',
	'search-minus',
	'power-off',
	'signal',
	'cog',
	'gear',
	'trash-o',
	'home',
	'file-o',
	'clock-o',
	'road',
	'download',
	'arrow-circle-o-down',
	'arrow-circle-o-up',
	'inbox',
	'play-circle-o',
	'repeat',
	'rotate-right',
	'refresh',
	'list-alt',
	'lock',
	'flag',
	'headphones',
	'volume-off',
	'volume-down',
	'volume-up',
	'qrcode',
	'barcode',
	'tag',
	'tags',
	'book',
	'bookmark',
	'print',
	'camera',
	'font',
	'bold',
	'italic',
	'text-height',
	'text-width',
	'align-left',
	'align-center',
	'align-right',
	'align-justify',
	'list',
	'outdent',
	'dedent',
	'indent',
	'video-camera',
	'picture-o',
	'photo',
	'image',
	'pencil',
	'map-marker',
	'adjust',
	'tint',
	'pencil-square-o',
	'edit',
	'share-square-o',
	'check-square-o',
	'arrows',
	'step-backward',
	'fast-backward',
	'backward',
	'play',
	'pause',
	'stop',
	'forward',
	'fast-forward',
	'step-forward',
	'eject',
	'chevron-left',
	'chevron-right',
	'plus-circle',
	'minus-circle',
	'times-circle',
	'check-circle',
	'question-circle',
	'info-circle',
	'crosshairs',
	'times-circle-o',
	'check-circle-o',
	'ban',
	'arrow-left',
	'arrow-right',
	'arrow-up',
	'arrow-down',
	'share',
	'mail-forward',
	'expand',
	'compress',
	'plus',
	'minus',
	'asterisk',
	'exclamation-circle',
	'gift',
	'leaf',
	'fire',
	'eye',
	'eye-slash',
	'exclamation-triangle',
	'warning',
	'plane',
	'calendar',
	'random',
	'comment',
	'magnet',
	'chevron-up',
	'chevron-down',
	'retweet',
	'shopping-cart',
	'folder',
	'folder-open',
	'arrows-v',
	'arrows-h',
	'bar-chart',
	'bar-chart-o',
	'twitter-square',
	'facebook-square',
	'camera-retro',
	'key',
	'cogs',
	'gears',
	'comments',
	'thumbs-o-up',
	'thumbs-o-down',
	'star-half',
	'heart-o',
	'sign-out',
	'linkedin-square',
	'thumb-tack',
	'external-link',
	'sign-in',
	'trophy',
	'github-square',
	'upload',
	'lemon-o',
	'phone',
	'square-o',
	'bookmark-o',
	'phone-square',
	'twitter',
	'facebook',
	'facebook-f',
	'github',
	'unlock',
	'credit-card',
	'rss',
	'feed',
	'hdd-o',
	'bullhorn',
	'bell',
	'certificate',
	'hand-o-right',
	'hand-o-left',
	'hand-o-up',
	'hand-o-down',
	'arrow-circle-left',
	'arrow-circle-right',
	'arrow-circle-up',
	'arrow-circle-down',
	'globe',
	'wrench',
	'tasks',
	'filter',
	'briefcase',
	'arrows-alt',
	'users',
	'group',
	'link',
	'chain',
	'cloud',
	'flask',
	'scissors',
	'cut',
	'files-o',
	'copy',
	'paperclip',
	'floppy-o',
	'save',
	'square',
	'bars',
	'navicon',
	'reorder',
	'list-ul',
	'list-ol',
	'strikethrough',
	'underline',
	'table',
	'magic',
	'truck',
	'pinterest',
	'pinterest-square',
	'google-plus-square',
	'google-plus',
	'money',
	'caret-down',
	'caret-up',
	'caret-left',
	'caret-right',
	'columns',
	'sort',
	'unsorted',
	'sort-desc',
	'sort-down',
	'sort-asc',
	'sort-up',
	'envelope',
	'linkedin',
	'undo',
	'rotate-left',
	'gavel',
	'legal',
	'tachometer',
	'dashboard',
	'comment-o',
	'comments-o',
	'bolt',
	'flash',
	'sitemap',
	'umbrella',
	'clipboard',
	'paste',
	'lightbulb-o',
	'exchange',
	'cloud-download',
	'cloud-upload',
	'user-md',
	'stethoscope',
	'suitcase',
	'bell-o',
	'coffee',
	'cutlery',
	'file-text-o',
	'building-o',
	'hospital-o',
	'ambulance',
	'medkit',
	'fighter-jet',
	'beer',
	'h-square',
	'plus-square',
	'angle-double-left',
	'angle-double-right',
	'angle-double-up',
	'angle-double-down',
	'angle-left',
	'angle-right',
	'angle-up',
	'angle-down',
	'desktop',
	'laptop',
	'tablet',
	'mobile',
	'mobile-phone',
	'circle-o',
	'quote-left',
	'quote-right',
	'spinner',
	'circle',
	'reply',
	'mail-reply',
	'github-alt',
	'folder-o',
	'folder-open-o',
	'smile-o',
	'frown-o',
	'meh-o',
	'gamepad',
	'keyboard-o',
	'flag-o',
	'flag-checkered',
	'terminal',
	'code',
	'reply-all',
	'mail-reply-all',
	'star-half-o',
	'star-half-empty',
	'star-half-full',
	'location-arrow',
	'crop',
	'code-fork',
	'chain-broken',
	'unlink',
	'question',
	'info',
	'exclamation',
	'superscript',
	'subscript',
	'eraser',
	'puzzle-piece',
	'microphone',
	'microphone-slash',
	'shield',
	'calendar-o',
	'fire-extinguisher',
	'rocket',
	'maxcdn',
	'chevron-circle-left',
	'chevron-circle-right',
	'chevron-circle-up',
	'chevron-circle-down',
	'html5',
	'css3',
	'anchor',
	'unlock-alt',
	'bullseye',
	'ellipsis-h',
	'ellipsis-v',
	'rss-square',
	'play-circle',
	'ticket',
	'minus-square',
	'minus-square-o',
	'level-up',
	'level-down',
	'check-square',
	'pencil-square',
	'external-link-square',
	'share-square',
	'compass',
	'caret-square-o-down',
	'toggle-down',
	'caret-square-o-up',
	'toggle-up',
	'caret-square-o-right',
	'toggle-right',
	'eur',
	'euro',
	'gbp',
	'usd',
	'dollar',
	'inr',
	'rupee',
	'jpy',
	'cny',
	'rmb',
	'yen',
	'rub',
	'ruble',
	'rouble',
	'krw',
	'won',
	'btc',
	'bitcoin',
	'file',
	'file-text',
	'sort-alpha-asc',
	'sort-alpha-desc',
	'sort-amount-asc',
	'sort-amount-desc',
	'sort-numeric-asc',
	'sort-numeric-desc',
	'thumbs-up',
	'thumbs-down',
	'youtube-square',
	'youtube',
	'xing',
	'xing-square',
	'youtube-play',
	'dropbox',
	'stack-overflow',
	'instagram',
	'flickr',
	'adn',
	'bitbucket',
	'bitbucket-square',
	'tumblr',
	'tumblr-square',
	'long-arrow-down',
	'long-arrow-up',
	'long-arrow-left',
	'long-arrow-right',
	'apple',
	'windows',
	'android',
	'linux',
	'dribbble',
	'skype',
	'foursquare',
	'trello',
	'female',
	'male',
	'gratipay',
	'gittip',
	'sun-o',
	'moon-o',
	'archive',
	'bug',
	'vk',
	'weibo',
	'renren',
	'pagelines',
	'stack-exchange',
	'arrow-circle-o-right',
	'arrow-circle-o-left',
	'caret-square-o-left',
	'toggle-left',
	'dot-circle-o',
	'wheelchair',
	'vimeo-square',
	'try',
	'turkish-lira',
	'plus-square-o',
	'space-shuttle',
	'slack',
	'envelope-square',
	'wordpress',
	'openid',
	'university',
	'institution',
	'bank',
	'graduation-cap',
	'mortar-board',
	'yahoo',
	'google',
	'reddit',
	'reddit-square',
	'stumbleupon-circle',
	'stumbleupon',
	'delicious',
	'digg',
	'pied-piper-pp',
	'pied-piper-alt',
	'drupal',
	'joomla',
	'language',
	'fax',
	'building',
	'child',
	'paw',
	'spoon',
	'cube',
	'cubes',
	'behance',
	'behance-square',
	'steam',
	'steam-square',
	'recycle',
	'car',
	'automobile',
	'taxi',
	'cab',
	'tree',
	'spotify',
	'deviantart',
	'soundcloud',
	'database',
	'file-pdf-o',
	'file-word-o',
	'file-excel-o',
	'file-powerpoint-o',
	'file-image-o',
	'file-photo-o',
	'file-picture-o',
	'file-archive-o',
	'file-zip-o',
	'file-audio-o',
	'file-sound-o',
	'file-video-o',
	'file-movie-o',
	'file-code-o',
	'vine',
	'codepen',
	'jsfiddle',
	'life-ring',
	'life-bouy',
	'life-buoy',
	'life-saver',
	'support',
	'circle-o-notch',
	'rebel',
	'ra',
	'resistance',
	'empire',
	'ge',
	'git-square',
	'git',
	'hacker-news',
	'y-combinator-square',
	'yc-square',
	'tencent-weibo',
	'qq',
	'weixin',
	'wechat',
	'paper-plane',
	'send',
	'paper-plane-o',
	'send-o',
	'history',
	'circle-thin',
	'header',
	'paragraph',
	'sliders',
	'share-alt',
	'share-alt-square',
	'bomb',
	'futbol-o',
	'soccer-ball-o',
	'tty',
	'binoculars',
	'plug',
	'slideshare',
	'twitch',
	'yelp',
	'newspaper-o',
	'wifi',
	'calculator',
	'paypal',
	'google-wallet',
	'cc-visa',
	'cc-mastercard',
	'cc-discover',
	'cc-amex',
	'cc-paypal',
	'cc-stripe',
	'bell-slash',
	'bell-slash-o',
	'trash',
	'copyright',
	'at',
	'eyedropper',
	'paint-brush',
	'birthday-cake',
	'area-chart',
	'pie-chart',
	'line-chart',
	'lastfm',
	'lastfm-square',
	'toggle-off',
	'toggle-on',
	'bicycle',
	'bus',
	'ioxhost',
	'angellist',
	'cc',
	'ils',
	'shekel',
	'sheqel',
	'meanpath',
	'buysellads',
	'connectdevelop',
	'dashcube',
	'forumbee',
	'leanpub',
	'sellsy',
	'shirtsinbulk',
	'simplybuilt',
	'skyatlas',
	'cart-plus',
	'cart-arrow-down',
	'diamond',
	'ship',
	'user-secret',
	'motorcycle',
	'street-view',
	'heartbeat',
	'venus',
	'mars',
	'mercury',
	'transgender',
	'intersex',
	'transgender-alt',
	'venus-double',
	'mars-double',
	'venus-mars',
	'mars-stroke',
	'mars-stroke-v',
	'mars-stroke-h',
	'neuter',
	'genderless',
	'facebook-official',
	'pinterest-p',
	'whatsapp',
	'server',
	'user-plus',
	'user-times',
	'bed',
	'hotel',
	'viacoin',
	'train',
	'subway',
	'medium',
	'y-combinator',
	'yc',
	'optin-monster',
	'opencart',
	'expeditedssl',
	'battery-full',
	'battery-4',
	'battery',
	'battery-three-quarters',
	'battery-3',
	'battery-half',
	'battery-2',
	'battery-quarter',
	'battery-1',
	'battery-empty',
	'battery-0',
	'mouse-pointer',
	'i-cursor',
	'object-group',
	'object-ungroup',
	'sticky-note',
	'sticky-note-o',
	'cc-jcb',
	'cc-diners-club',
	'clone',
	'balance-scale',
	'hourglass-o',
	'hourglass-start',
	'hourglass-1',
	'hourglass-half',
	'hourglass-2',
	'hourglass-end',
	'hourglass-3',
	'hourglass',
	'hand-rock-o',
	'hand-grab-o',
	'hand-paper-o',
	'hand-stop-o',
	'hand-scissors-o',
	'hand-lizard-o',
	'hand-spock-o',
	'hand-pointer-o',
	'hand-peace-o',
	'trademark',
	'registered',
	'creative-commons',
	'gg',
	'gg-circle',
	'tripadvisor',
	'odnoklassniki',
	'odnoklassniki-square',
	'get-pocket',
	'wikipedia-w',
	'safari',
	'chrome',
	'firefox',
	'opera',
	'internet-explorer',
	'television',
	'tv',
	'contao',
	'500px',
	'amazon',
	'calendar-plus-o',
	'calendar-minus-o',
	'calendar-times-o',
	'calendar-check-o',
	'industry',
	'map-pin',
	'map-signs',
	'map-o',
	'map',
	'commenting',
	'commenting-o',
	'houzz',
	'vimeo',
	'black-tie',
	'fonticons',
	'reddit-alien',
	'edge',
	'credit-card-alt',
	'codiepie',
	'modx',
	'fort-awesome',
	'usb',
	'product-hunt',
	'mixcloud',
	'scribd',
	'pause-circle',
	'pause-circle-o',
	'stop-circle',
	'stop-circle-o',
	'shopping-bag',
	'shopping-basket',
	'hashtag',
	'bluetooth',
	'bluetooth-b',
	'percent',
	'gitlab',
	'wpbeginner',
	'wpforms',
	'envira',
	'universal-access',
	'wheelchair-alt',
	'question-circle-o',
	'blind',
	'audio-description',
	'volume-control-phone',
	'braille',
	'assistive-listening-systems',
	'american-sign-language-interpreting',
	'asl-interpreting',
	'deaf',
	'deafness',
	'hard-of-hearing',
	'glide',
	'glide-g',
	'sign-language',
	'signing',
	'low-vision',
	'viadeo',
	'viadeo-square',
	'snapchat',
	'snapchat-ghost',
	'snapchat-square',
	'pied-piper',
	'first-order',
	'yoast',
	'themeisle',
	'google-plus-official',
	'google-plus-circle',
	'font-awesome',
	'fa',
	'handshake-o',
	'envelope-open',
	'envelope-open-o',
	'linode',
	'address-book',
	'address-book-o',
	'address-card',
	'vcard',
	'address-card-o',
	'vcard-o',
	'user-circle',
	'user-circle-o',
	'user-o',
	'id-badge',
	'id-card',
	'drivers-license',
	'id-card-o',
	'drivers-license-o',
	'quora',
	'free-code-camp',
	'telegram',
	'thermometer-full',
	'thermometer-4',
	'thermometer',
	'thermometer-three-quarters',
	'thermometer-3',
	'thermometer-half',
	'thermometer-2',
	'thermometer-quarter',
	'thermometer-1',
	'thermometer-empty',
	'thermometer-0',
	'shower',
	'bath',
	'bathtub',
	's15',
	'podcast',
	'window-maximize',
	'window-minimize',
	'window-restore',
	'window-close',
	'times-rectangle',
	'window-close-o',
	'times-rectangle-o',
	'bandcamp',
	'grav',
	'etsy',
	'imdb',
	'ravelry',
	'eercast',
	'microchip',
	'snowflake-o',
	'superpowers',
	'wpexplorer',
	'meetup',
]
# generate by tools/list_icons
